pub enum Restrict {
Const(usize),
Unify(usize),
}Expand description
A Restrict describes a way a particular Field can be limited in the join
Variants
Const(usize)
The value at Field must equal the provided value
Unify(usize)
The value at Field must equal all other values which were restricted by being Unify’d
to the same provided key