pub struct Field {
pub clause: usize,
pub field: usize,
}Expand description
A field specifies a particular value in the join problem
Fields
clause: usizeclause refers to which iterator this value comes from, based on the order they were
provided to the Join constructor
field: usizefield indicates offset into the tuple referred to